@@ -22,61 +22,61 @@ class ISBNToolsDevException(Exception):
         return getattr(self, 'message', '')       # pragma: no cover
 
 
-class WSHTTPError(ISBNToolsDevException):
+class ISBNToolsHTTPError(ISBNToolsDevException):
     """ Exception raised for HTTP related errors
     """
     message = "an HTTP error has ocurred"
 
 
-class WSURLError(ISBNToolsDevException):
+class ISBNToolsURLError(ISBNToolsDevException):
     """ Exception raised for URL related errors
     """
     message = "an URL error has ocurred"
 
 
-class WQDataNotFoundError(ISBNToolsDevException):
+class DataNotFoundAtServiceError(ISBNToolsDevException):
     """ Exception raised when there is no target data from the service
     """
-    message = "the target data was not found"
+    message = "the target data was not found at this service"
 
 
-class WQServiceIsDownError(ISBNToolsDevException):
+class ServiceIsDownError(ISBNToolsDevException):
     """ Exception raised when the service is not available
     """
     message = "the service is down (try later)"
 
 
-class WPDataWrongShapeError(ISBNToolsDevException):
+class DataWrongShapeError(ISBNToolsDevException):
     """ Exception raised when the data hasn't the expected format
     """
     message = "the data hasn't the expected format"
 
 
-class WPDataNotFoundError(ISBNToolsDevException):
-    """ Exception raised when the data isn't availabe at the service
+class NoDataForSelectorError(ISBNToolsDevException):
+    """ Exception raised when there is no data for the selector
     """
-    message = "the data isn't available at this service"
+    message = "no data for this selector"
 
 
-class WPNotValidMetadataError(ISBNToolsDevException):
+class NotValidMetadataError(ISBNToolsDevException):
     """ Exception raised when the metadata hasn't the expected format
     """
     message = "the metadata hasn't the expected format"
 
 
-class WPRecordMappingError(ISBNToolsDevException):
+class RecordMappingError(ISBNToolsDevException):
     """ Exception raised when the mapping records -> canonical doesn't work
     """
     message = "the mapping `canonical <- records` doesn't work"
 
 
-class WPNoAPIKeyError(ISBNToolsDevException):
+class NoAPIKeyError(ISBNToolsDevException):
     """ Exception raised when the API Key for a service is not found
     """
     message = "this service needs an API key"
 
 
-class WPNotImplementedError(ISBNToolsDevException):
+class NotImplementedError(ISBNToolsDevException):
     """ Exception raised when the methods wasn't implemented yet!
     """
     message = "this method wasn't implemented yet"
