@@ -4,8 +4,8 @@
 import logging
 from .webquery import WEBQuery
 from .data import stdmeta
-from .exceptions import (WPDataWrongShapeError, WPDataNotFoundError,
-                         WPRecordMappingError)
+from .exceptions import (DataWrongShapeError, NoDataForSelectorError,
+                         RecordMappingError)
 
 
 UA = 'isbntools (gzip)'
@@ -45,7 +45,7 @@ class WCATQuery(WEBQuery):
             canonical['Year'] = records.get('year', u'')
             canonical['Language'] = records.get('lang', u'')
         except:
-            raise WPRecordMappingError(self.isbn)
+            raise RecordMappingError(self.isbn)
         # call stdmeta for extra cleanning and validation
         return stdmeta(canonical)
 
@@ -61,11 +61,11 @@ class WCATQuery(WEBQuery):
         except:
             try:
                 extra = data['stat']
-                logger.debug('WPDataWrongShapeError for % with data %s' %
+                logger.debug('DataWrongShapeError for % with data %s' %
                              (self.isbn, extra))
             except:
-                raise WPDataWrongShapeError(self.isbn)
-            raise WPDataNotFoundError(self.isbn)
+                raise DataWrongShapeError(self.isbn)
+            raise NoDataForSelectorError(self.isbn)
 
         # map canonical <- records
         return self.mapper(records)
