@@ -11,10 +11,18 @@ from .dev import openl
 """
 Config file for metadata services
 """
-services = {'default': merge.query,   # <-- mandatory
+services = {'default': merge.query,      # <-- mandatory
             'wcat': wcat.query,
             'goob': googlebooks.query,
             'merge': merge.query,
             'isbndb': isbndb.query,
             'openl': openl.query,
             }
+
+
+def setdefaultservice(service_name):
+    """
+    Sets the default service
+    """
+    global services
+    services['default'] = services[service_name]
